---
name: Bug report
about: Create a report to help us improve
title: "[BUG]"
labels: 'Status: Review Needed, Type: Bug'
assignees: Stranger6667

---

**Describe the bug**
A clear and concise description of what the bug is.

**To Reproduce**
Steps to reproduce the behavior:

1. On this test file '...' (provide a minimal example)
2. Run this command '...'
3. See error

**Expected behavior**
A clear and concise description of what you expected to happen.

**Environment (please complete the following information):**

- OS: [e.g. Linux or Windows]
- Python version: [e.g. 3.7.2]
- pytest-recording version: [e.g. 0.9.0]
- pytest version: [e.g. 6.0]

**Additional context**
Add any other context about the problem here.
